(qdsl {:keys [tag] :as options} & body)Compiles a quandary domain and equation DSL body into a {:domain … :equations …} map
suitable for solve. Use collate to combine the output of multiple qdsl calls.
Options (first argument, a map):
:tag (String) — attaches provenance metadata to the result; useful for debugging
or conditionally disabling sections at runtime.:tap-entries (boolean) — when true, taps the intermediate entry structure produced
by macro expansion for inspection.:initial-context (map) — a {:domain …, :equations …} map that is collated with
the body before processing.A common pattern is to bind locals to results of $ and $# (or partials of them)
for concise variable name references in the body.
Compiles a quandary domain and equation DSL body into a `{:domain … :equations …}` map
suitable for `solve`. Use `collate` to combine the output of multiple `qdsl` calls.
Options (first argument, a map):
- `:tag` (String) — attaches provenance metadata to the result; useful for debugging
or conditionally disabling sections at runtime.
- `:tap-entries` (boolean) — when true, taps the intermediate entry structure produced
by macro expansion for inspection.
- `:initial-context` (map) — a `{:domain …, :equations …}` map that is collated with
the body before processing.
A common pattern is to bind locals to results of `$` and `$#` (or partials of them)
for concise variable name references in the body.(qdsl-from-resource {:keys [tag] :as options} path args)See qdsl.
path as a sequence of EDN objectargs is a sequence of values that matched the sequence of the :in value in the
first Map in the file.See `qdsl`. - Read file at resource `path` as a sequence of EDN object - `args` is a sequence of values that matched the sequence of the :in value in the first Map in the file.
(solve d-and-e)(solve {:keys [domain equations]} options)Solve a constraint satisfaction/optimization problem.
Accepts a map with :domain and :equations keys (as returned by qdsl or collate)
and an optional options map passed through to the underlying solver.
Solve a constraint satisfaction/optimization problem. Accepts a map with `:domain` and `:equations` keys (as returned by `qdsl` or `collate`) and an optional `options` map passed through to the underlying solver.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |