(basic-le)(basic-le-with-implies-and-only-if)(basic-le-with-quandary)(cp-example3)Using the CP-SAT solver for integers. All solutions.
Using the CP-SAT solver for integers. All solutions.
(rabbits-and-pheasants)Solve the Rabbits and Pheasants problem:
In a field of rabbits and pheasants, there are 20 heads and 56 legs. How many rabbits and pheasants are there? Hint: Rabbits have 4 legs, pheasants have 2.
See OR-Tools solutions in other languages at https://git.xkool.org/hw/or-tools/-/blob/e59073c45f054867ef4c80c99db94d985c9b5679/ortools/sat/doc/integer_arithmetic.md#rabbits-and-pheasants-examples
Solve the Rabbits and Pheasants problem: In a field of rabbits and pheasants, there are 20 heads and 56 legs. How many rabbits and pheasants are there? Hint: Rabbits have 4 legs, pheasants have 2. See OR-Tools solutions in other languages at https://git.xkool.org/hw/or-tools/-/blob/e59073c45f054867ef4c80c99db94d985c9b5679/ortools/sat/doc/integer_arithmetic.md#rabbits-and-pheasants-examples
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |