(ceil-div-o target x y)A form of integer division. A relation for target = ceil(x / y).
Also see quandary's add-division-equality eop, which also does division, but then
does floor on the result instead.
A form of integer division. A relation for `target = ceil(x / y)`. Also see quandary's `add-division-equality` eop, which also does division, but then does `floor` on the result instead.
(is-exclusive-betweeno pt start stop target-var)Returns domain and equations that set boolean target-var to true iff pt is strictly
inside the open interval (start, stop). When target-var is false, pt is constrained
to be at or outside the interval boundaries.
Returns domain and equations that set boolean `target-var` to true iff `pt` is strictly inside the open interval `(start, stop)`. When `target-var` is false, `pt` is constrained to be at or outside the interval boundaries.
(mean target terms total-lb total-ub)Calculate the mean average for the given terms. The result is equated to the target varname.
terms can be single varnames, with the values to compute.
Or tuples of [n value], meaning n occurrences of value.
N.B. In the latter case, the count, n, must be first.
Calculate the mean average for the given terms. The result is equated to the `target` varname. `terms` can be single varnames, with the values to compute. Or tuples of [n value], meaning `n` occurrences of `value`. N.B. In the latter case, the count, `n`, must be first.
(sqrto target x ub)Finds the floor square root. WARNING: Do not try to use this relation in reverse to get the square of a value. Instead, just multiply the value. E.g. y = x * x: ["=" ["y"] [["x" "x"]]]
Finds the floor square root. WARNING: Do not try to use this relation in reverse to get the square of a value. Instead, just multiply the value. E.g. y = x * x: ["=" ["y"] [["x" "x"]]]
(variance target terms total-lb total-ub)Calculate the variance for the given terms. See variance-from for more details.
NOTE: a safe total-ub can be derived as MAX(upper-bound of each term)^2 / 4
Calculate the variance for the given terms. See `variance-from` for more details. NOTE: a safe total-ub can be derived as `MAX(upper-bound of each term)^2 / 4`
(variance-from target mean-avg terms total-lb total-ub)Calculate the variance for the given terms. The result is equated to the target
varname.
Args
target - varname to set the result into
terms - can be single varnames, with the values to compute.
Or tuples of [n value], meaning n occurrences of value.
N.B. In the latter case, the count, n, must be first.
mean-avg - A var or a long
total-lb - Lower bound for temp vars (large enough to hold the total of all variables)
total-ub - Upper bound for temp vars
NOTE: a safe total-ub can be derived as MAX(upper-bound of each term)^2 / 4
Calculate the variance for the given terms. The result is equated to the `target`
varname.
Args
target - varname to set the result into
terms - can be single varnames, with the values to compute.
Or tuples of [n value], meaning `n` occurrences of `value`.
N.B. In the latter case, the count, `n`, must be first.
mean-avg - A var or a long
total-lb - Lower bound for temp vars (large enough to hold the total of all variables)
total-ub - Upper bound for temp vars
NOTE: a safe total-ub can be derived as `MAX(upper-bound of each term)^2 / 4`cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |