(collate & xs)Given a collection of Maps, collate the domain and equations and "other" keys into a single Map.
The "other" keys are merged using collate-merge, which can be extended with defmethod.
When input maps have metadata, that metadata is stored on the objects within the collation.
Given a collection of Maps, collate the domain and equations and "other" keys into a single Map. The "other" keys are merged using `collate-merge`, which can be extended with defmethod. When input maps have metadata, that metadata is stored on the objects within the collation.
Given a collection of Maps, collate the domain and equations and (given strategies via defmethod) other keys into a single Map.
Given a collection of Maps, collate the domain and equations and (given strategies via defmethod) other keys into a single Map.
(dollar-vars & body)A macro to make varname references easy. Will walk the form and replace any symbols of the form
$foo.x with the varname string for x from object foo. (i.e. appending x to the var-name-prefix from obj).
A macro to make varname references easy. Will walk the form and replace any symbols of the form `$foo.x` with the varname string for x from object foo. (i.e. appending x to the `var-name-prefix` from obj).
(dot values)(dot v0 v1 & more)Join the strings with dots (".")
Join the strings with dots (".")
(examine-equations equations)Groups equations by variable name for debugging. Returns a map of varname → [equations]. Note: hardcoded filters exclude scorer variables and wall-segment cs layout variables.
Groups equations by variable name for debugging. Returns a map of varname → [equations]. Note: hardcoded filters exclude scorer variables and wall-segment cs layout variables.
(merge-with-using-key f & maps)Returns a map that consists of the rest of the maps conj-ed onto the first. If a key occurs in more than one map, the mapping(s) from the latter (left-to-right) will be combined with the mapping in the result by calling (f key val-in-result val-in-latter).
Returns a map that consists of the rest of the maps conj-ed onto the first. If a key occurs in more than one map, the mapping(s) from the latter (left-to-right) will be combined with the mapping in the result by calling (f key val-in-result val-in-latter).
(next-id)(next-id s)Append the next ID (a sequential four digit numeric) String onto String s.
NEXT_ID must be bound in the local thread context to an atom with a long value, e.g.:
(binding [qutil/NEXT_ID (atom 0)]
(next-id "foo") ...)
Append the next ID (a sequential four digit numeric) String onto String `s`. *NEXT_ID* must be bound in the local thread context to an atom with a long value, e.g.: (binding [qutil/*NEXT_ID* (atom 0)] (next-id "foo") ...)
(ordered-domain? context rules)A validation function to test if domain is ordered. An ordered domain is not a requirement, but is helpful for debugging and determinism.
A validation function to test if domain is ordered. An ordered domain is not a requirement, but is helpful for debugging and determinism.
(parse-cvar s)Parses an application-specific variable name of the form wall.X.S.N.C.M.suffix into
[prefix wallid slot cidx suffix] where prefix is "wall.X.S.N.C.M".
Returns nil if s is nil or does not match.
Parses an application-specific variable name of the form `wall.X.S.N.C.M.suffix` into `[prefix wallid slot cidx suffix]` where prefix is `"wall.X.S.N.C.M"`. Returns nil if `s` is nil or does not match.
(utc-now)Returns the current instant as a ZonedDateTime in UTC.
Returns the current instant as a `ZonedDateTime` in UTC.
(var-name-from obj suffix & [temp?])Constructs a dot-joined variable name from obj's ::q/var-name-prefix and suffix.
When temp? is truthy, prepends "TEMP" to produce a temp variable name.
Constructs a dot-joined variable name from `obj`'s `::q/var-name-prefix` and `suffix`. When `temp?` is truthy, prepends `"TEMP"` to produce a temp variable name.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |